@@ -26,13 +26,20 @@ def LPrint(*args,**kwargs):
         print ('--print info>>>',end='')
     else:
         print (str(args).decode('unicode_escape'),'--info>>>  ',end='')
-    print ('{}{}{},line--{},fn--{}{}'.
-        format( bcolors.OKBLUE,
-                os.path.basename(caller.filename),
-                bcolors.ENDC,
+    # if sys.version[0]=='3':
+    #     print (u'{}{}{},line--{},fn--{}{}'.
+    #         format( bcolors.OKBLUE,
+    #                 os.path.basename(caller.filename),
+    #                 bcolors.ENDC,
+    #                 caller.lineno,
+    #                 caller.function,
+    #                 bcolors.ENDC),end=kwargs['end'])
+    # else:
+    print (u'{},line--{},fn--{}'.
+        format( os.path.basename(caller.filename),
                 caller.lineno,
                 caller.function,
-                bcolors.ENDC),end=kwargs['end'])
+                ),end=kwargs['end'])
 
 def test_LPrint():
     LPrint ((u'你好',u'世界',{u'你好':u'世界'},(u'你好',u'世界')),end='\n\n')
